depends = ('ITKPyBase', 'ITKNarrowBand', 'ITKImageLabel', 'ITKBinaryMathematicalMorphology', )
templates = (
  ('ApproximateSignedDistanceMapImageFilter', 'itk::ApproximateSignedDistanceMapImageFilter', 'itkApproximateSignedDistanceMapImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('ApproximateSignedDistanceMapImageFilter', 'itk::ApproximateSignedDistanceMapImageFilter', 'itkApproximateSignedDistanceMapImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('ApproximateSignedDistanceMapImageFilter', 'itk::ApproximateSignedDistanceMapImageFilter', 'itkApproximateSignedDistanceMapImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ApproximateSignedDistanceMapImageFilter', 'itk::ApproximateSignedDistanceMapImageFilter', 'itkApproximateSignedDistanceMapImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('ApproximateSignedDistanceMapImageFilter', 'itk::ApproximateSignedDistanceMapImageFilter', 'itkApproximateSignedDistanceMapImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('ApproximateSignedDistanceMapImageFilter', 'itk::ApproximateSignedDistanceMapImageFilter', 'itkApproximateSignedDistanceMapImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('ContourDirectedMeanDistanceImageFilter', 'itk::ContourDirectedMeanDistanceImageFilter', 'itkContourDirectedMeanDistanceImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('ContourDirectedMeanDistanceImageFilter', 'itk::ContourDirectedMeanDistanceImageFilter', 'itkContourDirectedMeanDistanceImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('ContourDirectedMeanDistanceImageFilter', 'itk::ContourDirectedMeanDistanceImageFilter', 'itkContourDirectedMeanDistanceImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ContourDirectedMeanDistanceImageFilter', 'itk::ContourDirectedMeanDistanceImageFilter', 'itkContourDirectedMeanDistanceImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('ContourDirectedMeanDistanceImageFilter', 'itk::ContourDirectedMeanDistanceImageFilter', 'itkContourDirectedMeanDistanceImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('ContourDirectedMeanDistanceImageFilter', 'itk::ContourDirectedMeanDistanceImageFilter', 'itkContourDirectedMeanDistanceImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('ContourDirectedMeanDistanceImageFilter', 'itk::ContourDirectedMeanDistanceImageFilter', 'itkContourDirectedMeanDistanceImageFilterIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('ContourDirectedMeanDistanceImageFilter', 'itk::ContourDirectedMeanDistanceImageFilter', 'itkContourDirectedMeanDistanceImageFilterIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('ContourDirectedMeanDistanceImageFilter', 'itk::ContourDirectedMeanDistanceImageFilter', 'itkContourDirectedMeanDistanceImageFilterIUC2ID2', True, 'itk::Image< unsigned char,2 >, itk::Image< double,2 >'),
  ('ContourDirectedMeanDistanceImageFilter', 'itk::ContourDirectedMeanDistanceImageFilter', 'itkContourDirectedMeanDistanceImageFilterIUC3ID3', True, 'itk::Image< unsigned char,3 >, itk::Image< double,3 >'),
  ('ContourDirectedMeanDistanceImageFilter', 'itk::ContourDirectedMeanDistanceImageFilter', 'itkContourDirectedMeanDistanceImageFilterIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('ContourDirectedMeanDistanceImageFilter', 'itk::ContourDirectedMeanDistanceImageFilter', 'itkContourDirectedMeanDistanceImageFilterIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('ContourDirectedMeanDistanceImageFilter', 'itk::ContourDirectedMeanDistanceImageFilter', 'itkContourDirectedMeanDistanceImageFilterIUS2ID2', True, 'itk::Image< unsigned short,2 >, itk::Image< double,2 >'),
  ('ContourDirectedMeanDistanceImageFilter', 'itk::ContourDirectedMeanDistanceImageFilter', 'itkContourDirectedMeanDistanceImageFilterIUS3ID3', True, 'itk::Image< unsigned short,3 >, itk::Image< double,3 >'),
  ('ContourMeanDistanceImageFilter', 'itk::ContourMeanDistanceImageFilter', 'itkContourMeanDistanceImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('ContourMeanDistanceImageFilter', 'itk::ContourMeanDistanceImageFilter', 'itkContourMeanDistanceImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('ContourMeanDistanceImageFilter', 'itk::ContourMeanDistanceImageFilter', 'itkContourMeanDistanceImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ContourMeanDistanceImageFilter', 'itk::ContourMeanDistanceImageFilter', 'itkContourMeanDistanceImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('ContourMeanDistanceImageFilter', 'itk::ContourMeanDistanceImageFilter', 'itkContourMeanDistanceImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('ContourMeanDistanceImageFilter', 'itk::ContourMeanDistanceImageFilter', 'itkContourMeanDistanceImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('ContourMeanDistanceImageFilter', 'itk::ContourMeanDistanceImageFilter', 'itkContourMeanDistanceImageFilterIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('ContourMeanDistanceImageFilter', 'itk::ContourMeanDistanceImageFilter', 'itkContourMeanDistanceImageFilterIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('ContourMeanDistanceImageFilter', 'itk::ContourMeanDistanceImageFilter', 'itkContourMeanDistanceImageFilterIUC2ID2', True, 'itk::Image< unsigned char,2 >, itk::Image< double,2 >'),
  ('ContourMeanDistanceImageFilter', 'itk::ContourMeanDistanceImageFilter', 'itkContourMeanDistanceImageFilterIUC3ID3', True, 'itk::Image< unsigned char,3 >, itk::Image< double,3 >'),
  ('ContourMeanDistanceImageFilter', 'itk::ContourMeanDistanceImageFilter', 'itkContourMeanDistanceImageFilterIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('ContourMeanDistanceImageFilter', 'itk::ContourMeanDistanceImageFilter', 'itkContourMeanDistanceImageFilterIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('ContourMeanDistanceImageFilter', 'itk::ContourMeanDistanceImageFilter', 'itkContourMeanDistanceImageFilterIUS2ID2', True, 'itk::Image< unsigned short,2 >, itk::Image< double,2 >'),
  ('ContourMeanDistanceImageFilter', 'itk::ContourMeanDistanceImageFilter', 'itkContourMeanDistanceImageFilterIUS3ID3', True, 'itk::Image< unsigned short,3 >, itk::Image< double,3 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterIUC2ID2', True, 'itk::Image< unsigned char,2 >, itk::Image< double,2 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterIUC3ID3', True, 'itk::Image< unsigned char,3 >, itk::Image< double,3 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterIUS2ID2', True, 'itk::Image< unsigned short,2 >, itk::Image< double,2 >'),
  ('DanielssonDistanceMapImageFilter', 'itk::DanielssonDistanceMapImageFilter', 'itkDanielssonDistanceMapImageFilterIUS3ID3', True, 'itk::Image< unsigned short,3 >, itk::Image< double,3 >'),
  ('DirectedHausdorffDistanceImageFilter', 'itk::DirectedHausdorffDistanceImageFilter', 'itkDirectedHausdorffDistanceImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('DirectedHausdorffDistanceImageFilter', 'itk::DirectedHausdorffDistanceImageFilter', 'itkDirectedHausdorffDistanceImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('DirectedHausdorffDistanceImageFilter', 'itk::DirectedHausdorffDistanceImageFilter', 'itkDirectedHausdorffDistanceImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('DirectedHausdorffDistanceImageFilter', 'itk::DirectedHausdorffDistanceImageFilter', 'itkDirectedHausdorffDistanceImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('DirectedHausdorffDistanceImageFilter', 'itk::DirectedHausdorffDistanceImageFilter', 'itkDirectedHausdorffDistanceImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('DirectedHausdorffDistanceImageFilter', 'itk::DirectedHausdorffDistanceImageFilter', 'itkDirectedHausdorffDistanceImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('DirectedHausdorffDistanceImageFilter', 'itk::DirectedHausdorffDistanceImageFilter', 'itkDirectedHausdorffDistanceImageFilterIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('DirectedHausdorffDistanceImageFilter', 'itk::DirectedHausdorffDistanceImageFilter', 'itkDirectedHausdorffDistanceImageFilterIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('DirectedHausdorffDistanceImageFilter', 'itk::DirectedHausdorffDistanceImageFilter', 'itkDirectedHausdorffDistanceImageFilterIUC2ID2', True, 'itk::Image< unsigned char,2 >, itk::Image< double,2 >'),
  ('DirectedHausdorffDistanceImageFilter', 'itk::DirectedHausdorffDistanceImageFilter', 'itkDirectedHausdorffDistanceImageFilterIUC3ID3', True, 'itk::Image< unsigned char,3 >, itk::Image< double,3 >'),
  ('DirectedHausdorffDistanceImageFilter', 'itk::DirectedHausdorffDistanceImageFilter', 'itkDirectedHausdorffDistanceImageFilterIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('DirectedHausdorffDistanceImageFilter', 'itk::DirectedHausdorffDistanceImageFilter', 'itkDirectedHausdorffDistanceImageFilterIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('DirectedHausdorffDistanceImageFilter', 'itk::DirectedHausdorffDistanceImageFilter', 'itkDirectedHausdorffDistanceImageFilterIUS2ID2', True, 'itk::Image< unsigned short,2 >, itk::Image< double,2 >'),
  ('DirectedHausdorffDistanceImageFilter', 'itk::DirectedHausdorffDistanceImageFilter', 'itkDirectedHausdorffDistanceImageFilterIUS3ID3', True, 'itk::Image< unsigned short,3 >, itk::Image< double,3 >'),
  ('FastChamferDistanceImageFilter', 'itk::FastChamferDistanceImageFilter', 'itkFastChamferDistanceImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('FastChamferDistanceImageFilter', 'itk::FastChamferDistanceImageFilter', 'itkFastChamferDistanceImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('FastChamferDistanceImageFilter', 'itk::FastChamferDistanceImageFilter', 'itkFastChamferDistanceImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('FastChamferDistanceImageFilter', 'itk::FastChamferDistanceImageFilter', 'itkFastChamferDistanceImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('FastChamferDistanceImageFilter', 'itk::FastChamferDistanceImageFilter', 'itkFastChamferDistanceImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('FastChamferDistanceImageFilter', 'itk::FastChamferDistanceImageFilter', 'itkFastChamferDistanceImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('HausdorffDistanceImageFilter', 'itk::HausdorffDistanceImageFilter', 'itkHausdorffDistanceImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('HausdorffDistanceImageFilter', 'itk::HausdorffDistanceImageFilter', 'itkHausdorffDistanceImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('HausdorffDistanceImageFilter', 'itk::HausdorffDistanceImageFilter', 'itkHausdorffDistanceImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('HausdorffDistanceImageFilter', 'itk::HausdorffDistanceImageFilter', 'itkHausdorffDistanceImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('HausdorffDistanceImageFilter', 'itk::HausdorffDistanceImageFilter', 'itkHausdorffDistanceImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('HausdorffDistanceImageFilter', 'itk::HausdorffDistanceImageFilter', 'itkHausdorffDistanceImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('HausdorffDistanceImageFilter', 'itk::HausdorffDistanceImageFilter', 'itkHausdorffDistanceImageFilterIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('HausdorffDistanceImageFilter', 'itk::HausdorffDistanceImageFilter', 'itkHausdorffDistanceImageFilterIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('HausdorffDistanceImageFilter', 'itk::HausdorffDistanceImageFilter', 'itkHausdorffDistanceImageFilterIUC2ID2', True, 'itk::Image< unsigned char,2 >, itk::Image< double,2 >'),
  ('HausdorffDistanceImageFilter', 'itk::HausdorffDistanceImageFilter', 'itkHausdorffDistanceImageFilterIUC3ID3', True, 'itk::Image< unsigned char,3 >, itk::Image< double,3 >'),
  ('HausdorffDistanceImageFilter', 'itk::HausdorffDistanceImageFilter', 'itkHausdorffDistanceImageFilterIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('HausdorffDistanceImageFilter', 'itk::HausdorffDistanceImageFilter', 'itkHausdorffDistanceImageFilterIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('HausdorffDistanceImageFilter', 'itk::HausdorffDistanceImageFilter', 'itkHausdorffDistanceImageFilterIUS2ID2', True, 'itk::Image< unsigned short,2 >, itk::Image< double,2 >'),
  ('HausdorffDistanceImageFilter', 'itk::HausdorffDistanceImageFilter', 'itkHausdorffDistanceImageFilterIUS3ID3', True, 'itk::Image< unsigned short,3 >, itk::Image< double,3 >'),
  ('IsoContourDistanceImageFilter', 'itk::IsoContourDistanceImageFilter', 'itkIsoContourDistanceImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('IsoContourDistanceImageFilter', 'itk::IsoContourDistanceImageFilter', 'itkIsoContourDistanceImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('IsoContourDistanceImageFilter', 'itk::IsoContourDistanceImageFilter', 'itkIsoContourDistanceImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('IsoContourDistanceImageFilter', 'itk::IsoContourDistanceImageFilter', 'itkIsoContourDistanceImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('SignedDanielssonDistanceMapImageFilter', 'itk::SignedDanielssonDistanceMapImageFilter', 'itkSignedDanielssonDistanceMapImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('SignedDanielssonDistanceMapImageFilter', 'itk::SignedDanielssonDistanceMapImageFilter', 'itkSignedDanielssonDistanceMapImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('SignedDanielssonDistanceMapImageFilter', 'itk::SignedDanielssonDistanceMapImageFilter', 'itkSignedDanielssonDistanceMapImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('SignedDanielssonDistanceMapImageFilter', 'itk::SignedDanielssonDistanceMapImageFilter', 'itkSignedDanielssonDistanceMapImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('SignedDanielssonDistanceMapImageFilter', 'itk::SignedDanielssonDistanceMapImageFilter', 'itkSignedDanielssonDistanceMapImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('SignedDanielssonDistanceMapImageFilter', 'itk::SignedDanielssonDistanceMapImageFilter', 'itkSignedDanielssonDistanceMapImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('SignedDanielssonDistanceMapImageFilter', 'itk::SignedDanielssonDistanceMapImageFilter', 'itkSignedDanielssonDistanceMapImageFilterIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('SignedDanielssonDistanceMapImageFilter', 'itk::SignedDanielssonDistanceMapImageFilter', 'itkSignedDanielssonDistanceMapImageFilterIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('SignedDanielssonDistanceMapImageFilter', 'itk::SignedDanielssonDistanceMapImageFilter', 'itkSignedDanielssonDistanceMapImageFilterIUC2ID2', True, 'itk::Image< unsigned char,2 >, itk::Image< double,2 >'),
  ('SignedDanielssonDistanceMapImageFilter', 'itk::SignedDanielssonDistanceMapImageFilter', 'itkSignedDanielssonDistanceMapImageFilterIUC3ID3', True, 'itk::Image< unsigned char,3 >, itk::Image< double,3 >'),
  ('SignedDanielssonDistanceMapImageFilter', 'itk::SignedDanielssonDistanceMapImageFilter', 'itkSignedDanielssonDistanceMapImageFilterIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('SignedDanielssonDistanceMapImageFilter', 'itk::SignedDanielssonDistanceMapImageFilter', 'itkSignedDanielssonDistanceMapImageFilterIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('SignedDanielssonDistanceMapImageFilter', 'itk::SignedDanielssonDistanceMapImageFilter', 'itkSignedDanielssonDistanceMapImageFilterIUS2ID2', True, 'itk::Image< unsigned short,2 >, itk::Image< double,2 >'),
  ('SignedDanielssonDistanceMapImageFilter', 'itk::SignedDanielssonDistanceMapImageFilter', 'itkSignedDanielssonDistanceMapImageFilterIUS3ID3', True, 'itk::Image< unsigned short,3 >, itk::Image< double,3 >'),
  ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterIUC2ID2', True, 'itk::Image< unsigned char,2 >, itk::Image< double,2 >'),
  ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterIUC3ID3', True, 'itk::Image< unsigned char,3 >, itk::Image< double,3 >'),
  ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterIUS2ID2', True, 'itk::Image< unsigned short,2 >, itk::Image< double,2 >'),
  ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterIUS3ID3', True, 'itk::Image< unsigned short,3 >, itk::Image< double,3 >'),
)
snake_case_functions = ('approximate_signed_distance_map_image_filter', 'signed_danielsson_distance_map_image_filter', 'danielsson_distance_map_image_filter', 'signed_maurer_distance_map_image_filter', 'contour_directed_mean_distance_image_filter', 'contour_mean_distance_image_filter', 'hausdorff_distance_image_filter', 'directed_hausdorff_distance_image_filter', 'fast_chamfer_distance_image_filter', 'iso_contour_distance_image_filter', )
